@@ -284,7 +284,10 @@ class HttpRepository(ArtifactsRepository):
         return BytesIO(r.content)
 
     def push(self, file_object, remote_name):
-        for wait in [1, 2, 4]:
+        # allow for a few attempts with increasing delay to account
+        # for temporary unavailabilities of the service
+        for wait in [0, 1, 2, 4, 8, 16, 32, 64, 128, 256]:
+            sleep(wait)
             r = put(
                 urljoin(self.uri, remote_name),
                 data=file_object,
@@ -293,7 +296,6 @@ class HttpRepository(ArtifactsRepository):
             if r.status_code == HTTPStatus.CREATED:
                 logging.debug(f"Successfully pushed to {remote_name}")
                 return True
-            sleep(wait)
         logging.error(
             f"Failed to push the artifact to {remote_name}.\n"
             f"Status code: {r.status_code}\n"
